import { without, pick, mapValues } from 'lodash-es';
import { computed, defineComponent, openBlock, createElementBlock, normalizeStyle, unref, createTextVNode, toDisplayString, createCommentVNode } from 'vue';

const bTextDefaultProps = {
    content: '文本内容',
    whiteSpace: 'normal',
    isRichText: false,
    //组件属性
    layerName: '',
    isDisplay: true,
    fieldTag: '',
    clickEvent: '',
    displayCondition: '',
    //组件样式
    display: 'flex',
    alignItems: '',
    justifyContent: '',
    transform: 'rotate(0deg)',
    color: 'rgba(0,0,0,1)',
    // textAlign: '', //水平对齐
    fontFamily: '',
    fontSize: '16px',
    fontWeight: 'normal',
    fontStyle: 'normal',
    textDecoration: 'none',
    overflow: 'hidden',
    cursor: 'auto',
    lineHeight: '16px',
    letterSpacing: '0px',
    textIndent: '0px',
    opacity: '100%',
    width: '200px',
    height: '100px',
    left: '0px',
    top: '0px',
    backgroundColor: 'rgba(0,0,0,0)',
    // backgroundImage: '', //背景图片
    // backgroundPosition: '', //背景图片位置
    // backgroundSize: '', //背景图片大小
    // backgroundRepeat: 'repeat', //背景图像重复
    paddingTop: '0px',
    paddingRight: '0px',
    paddingBottom: '0px',
    paddingLeft: '0px',
    borderRadius: '0 !important',
    borderTopLeftRadius: '0px',
    borderTopRightRadius: '0px',
    borderBottomLeftRadius: '0px',
    borderBottomRightRadius: '0px',
    // borderLeftStyle: 'solid', //左边框样式
    // borderLeftWidth: '0px', //左边框大小
    // borderLeftColor: '#000000', //左边框颜色
    // borderRightStyle: 'solid', //右边框样式
    // borderRightWidth: '0px', //右边框大小
    // borderRightColor: '#000000', //右边框颜色
    // borderTopStyle: 'solid', //上边框样式
    // borderTopWidth: '0px', //上边框大小
    // borderTopColor: '#000000', //上边框颜色
    // borderBottomStyle: 'solid', //下边框样式
    // borderBottomWidth: '0px', //下边框大小
    // borderBottomColor: '#000000', //下边框颜色
    borderStyle: 'solid',
    borderWidth: '0px',
    borderColor: 'rgba(0,0,0,0)',
    boxShadow: '0px 0px 0px 0px rgba(0,0,0,0)',
    boxShadowH: '0px',
    boxShadowV: '0px',
    boxShadowBlur: '0px',
    boxShadowSpread: '0px',
    boxShadowColor: 'rgba(0,0,0,0)',
    boxShadowInset: false, //内外阴影
};
const bTextStylePropNames = without(Object.keys(bTextDefaultProps), 'layerName', 'isDisplay', 'fieldTag', 'clickEvent', 'displayCondition', 'content', 'isWrap', 'isRichText');

const useComponentCommon = (props, picks) => {
    const styleProps = computed(() => pick(props, picks));
    return {
        styleProps
    };
};

const transformToComponentProps = (props) => {
    const mapProps = mapValues(props, (item) => {
        return {
            type: item.constructor,
            default: item
        };
    });
    return { ...mapProps };
};

const defaultProps = transformToComponentProps(bTextDefaultProps);
const __default__ = {
    name: "b-text",
};
var script = /*#__PURE__*/ defineComponent({
    ...__default__,
    props: {
        ...defaultProps,
    },
    setup(__props) {
        const props = __props;
        const { styleProps } = useComponentCommon(props, bTextStylePropNames);
        return (_ctx, _cache) => {
            return (props.isDisplay)
                ? (openBlock(), createElementBlock("div", {
                    key: 0,
                    style: normalizeStyle(unref(styleProps))
                }, [
                    createTextVNode(toDisplayString(_ctx.content), 1 /* TEXT */),
                    createCommentVNode(" <span v-if=\"props.isRichText\" v-html=\"content\"></span>\n    <span v-else>{{ content }}</span> ")
                ], 4 /* STYLE */))
                : createCommentVNode("v-if", true);
        };
    }
});

script.__file = "src/components/BText/BText.vue";

script.install = (app) => {
    app.component(script.name, script);
};

const components = [
    script
];
const install = (app) => {
    components.forEach(component => {
        app.component(component.name, component);
    });
};
var index = {
    install
};

export { script as BText, bTextDefaultProps, bTextStylePropNames, index as default, install };
